import React, { useImperativeHandle, forwardRef } from "react";
import { DownOutlined, PlusOutlined } from "@ant-design/icons";
import type { MenuProps } from "antd";
import { Dropdown, Space, Drawer, Button, Checkbox, Input } from "antd";
import { useModel } from "umi";
import { TodoItem } from "@/type";
import { uuid } from "@/utils";

const TodoDrawer = forwardRef((props: {}, ref) => {
  const [open, setOpen] = React.useState(false);
  const { project, setProject } = useModel("erModel");

  useImperativeHandle(ref, () => ({
    open: () => setOpen(true),
    close: () => setOpen(false),
  }));

  const items: MenuProps["items"] = [
    {
      key: "1",
      label: "按优先级排序",
    },
    {
      key: "2",
      label: "按完成时间排序",
    },
    {
      key: "3",
      label: "按创建时间排序",
    },
  ];

  const levelMap = {
    0: {
      label: "无",
      color: "gray",
    },
    1: {
      label: "低",
      color: "green",
    },
    2: {
      label: "中",
      color: "orange",
    },
    3: {
      label: "高",
      color: "red",
    },
  };

  const handleChange = (index: number, key: string, value: any) => {
    const newTodos = [...project.todos];
    newTodos[index] = {
      ...newTodos[index],
      [key]: value,
    };
    setProject({
      ...project,
      todos: newTodos,
    });
  };

  const addToto = () => {
    setProject({
      ...project,
      todos: [
        ...project.todos,
        {
          id: uuid(),
          name: "",
          text: "",
          isDone: false,
          level: 1,
        },
      ],
    });
  }

  return (
    <Drawer
      open={open}
      placement="right"
      width={400}
      title={<>待办事项</>}
      onClose={() => setOpen(false)}
    >
      <div className="flex justify-between m-b-12px">
        <Dropdown menu={{ items }}>
          <Space>
            排序方式
            <DownOutlined />
          </Space>
        </Dropdown>
        <Button type="primary" icon={<PlusOutlined />}>
          新建待办
        </Button>
      </div>
      {project.todos.map((todo: TodoItem, index: number) => (
        <div className="todo-item flex border-b-1 border-b-solid border-#eee p-b-12px">
          <div className="left m-r-12px">
            <Checkbox
              checked={todo.isDone}
              onChange={(e) => {
                handleChange(index, "isDone", e.target.checked);
              }}
            />
          </div>
          <div className="right flex-1">
            <div className="flex m-b-12px">
              <Input
                placeholder="标题..."
                value={todo.name}
                onChange={(e) => handleChange(index, "name", e.target.value)}
              />
              <div className="rounded-4px cus-btn w-32px h-32px bg-#eee flex-none text-center leading-32px cursor-pointer hover:bg-#ddd m-l-12px">
                <i className="iconfont icon-gengduo" />
              </div>
            </div>
            <div className="m-b-12px">
              <Input.TextArea
                placeholder="描述..."
                value={todo.text}
                onChange={(e) => handleChange(index, "text", e.target.value)}
              />
            </div>
            <div>
              优先级:{" "}
              <span className="inline-block w-20px h-20px bg-red-500 text-center color-#fff leading-16px rounded-4px">
                高
              </span>
            </div>
          </div>
        </div>
      ))}
    </Drawer>
  );
});

export default TodoDrawer;
